`kubernetes` deploys MLOps `stack` on top of Cloud provider's kubernetes. In case of AWS, its EKS.


#### Complete

===+ "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/complete/aws-complete.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/complete/aws-complete-advanced.yaml"
    ```

#### lakefs

===+ "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/lakefs/aws-lakefs.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/lakefs/aws-lakefs-advanced.yaml"
    ```

#### mlflow

===+ "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/mlflow/aws-mlflow.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/mlflow/aws-mlflow-advanced.yaml"
    ```

#### Prefect (Server & Worker)

===+ "Simple Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/prefect/aws-prefect.yaml"
    ```
=== "Advanced Deployment Configuration"
    ```yaml
    --8<-- "docs/examples/kubernetes/prefect/aws-prefect-advanced.yaml"
    ```
